@@ -8,7 +8,7 @@ use Moose;
 use Net::Rexster::Request;
 
 use version; 
-our $VERSION = qv('0.0.1');
+our $VERSION = qv('0.0.2');
 
 has 'server' => (is => 'rw', isa => 'Str', default => 'http://localhost:8182');
 has 'graph'  => (is => 'rw', isa => 'Str', required => 1);
@@ -400,7 +400,7 @@ Net::Rexster::Client - Handle Rexster REST request and response
 
 =head1 VERSION
 
-This document describes Net::Rexster version 0.0.1
+This document describes Net::Rexster version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -415,8 +415,6 @@ This document describes Net::Rexster version 0.0.1
     
     # Add property. 
     $c->create_vertex_property($id1, { 'dateOfBirth' => 'Dec 26' });
-    # URI encoding is done internally. This example is Japanese
-    $c->create_vertex_property($id1, { '生年月日' => '１２月２６日' });
     
     # Create edge with label, friend
     $c->create_edge($id1, "friend", $id2);
@@ -597,82 +595,14 @@ remove the vertex $id from $index at $key/$value
     classes provided by the module.
 
 
-=head1 DIAGNOSTICS
-
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
 Net::Rexster requires no configuration files or environment variables.
 
-
-=head1 DEPENDENCIES
-
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
-
-=head1 INCOMPATIBILITIES
-
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
-None reported.
-
-
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-net-rexster@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-
 =head1 AUTHOR
 
 Shohei Kameda  C<< <shoheik@cpan.org> >>
